@@ -24,14 +24,3 @@
 NULL
 
 
-.onAttach <- function(libname, pkgname) {
-  if(!requireNamespace("multtest", quietly = TRUE)){
-    packageStartupMessage(paste0("Welcome to metagam\n\n",
-                                "For the package to work properly, please install 'multtest':\n",
-                                "if (!requireNamespace('BiocManager', quietly = TRUE)) install.packages('BiocManager')\n",
-                                "BiocManager::install('multtest')"
-                                ))
-
-  }
-
-}
